

# To run this script you need to install Python and the serial library for Python so it can connect to the printer.
# You can install Python from the Microsoft App Sore. You can install the serial library by going to command line and typing "pip install pyserial".
# Set the com port number of baud rate for your Marlin mainboard below. You can also enable or dissable log keeping.
# To setup your Marlin mainboard to control manually, use pronterface.exe (www.pronterface.com)


import sys
import serial

# Define com port and baud rate
COM_PORT = 'COM7'
BAUD_RATE = 115200

# Enable or disable log keeping with "True" or "False"
ENABLE_LOGS = True 

def save_arguments_to_file(arguments, filename):
    if ENABLE_LOGS:
        with open(filename, 'a') as file:
            argument_string = ' '.join(arguments)
            file.write(argument_string + '\n')

def save_commands_to_printer_log(commands, filename):
    if ENABLE_LOGS:
        with open(filename, 'a') as file:
            for command in commands:
                file.write(command.strip() + '\n')

def send_to_printer(x_position):
    if x_position is not None:
        gcode_commands = [
            "G90",                   # Set absolute positioning mode
            f"G1 X{x_position:.2f}"  # Move to the specified X position
        ]
    else:
        gcode_commands = [
            "G28 X"                  # Home the X axis
        ]

    try:
        with serial.Serial(COM_PORT, BAUD_RATE, timeout=1) as ser:
            for command in gcode_commands:
                ser.write((command + '\n').encode())
                print(f"Sent to printer: {command}")
    except Exception as e:
        print(f"Error communicating with printer: {e}")

    # Save the commands to the printer log file
    printer_log_filename = 'Printer_Commands_Log.txt'
    save_commands_to_printer_log(gcode_commands, printer_log_filename)

if __name__ == "__main__":
    # Extract command line arguments excluding the script name
    command_line_arguments = sys.argv[1:]

    # Save arguments by appending to the log file
    log_filename = 'Arta_Commands_Log.txt'
    save_arguments_to_file(command_line_arguments, log_filename)

    # Interpret the first command line argument
    x_position = None
    if command_line_arguments:
        if command_line_arguments[0] != "-r":
            try:
                x_position = float(command_line_arguments[0])
            except ValueError:
                pass

    # Send the appropriate G-code commands based on the argument
    send_to_printer(x_position)

    print(f"Command line arguments and printer commands appended to {log_filename} and {printer_log_filename}")
